
------------------------------------------------------------------------
--
-- GridStatusAbsorbsMonitor
--
-- Copyright (C) 2010  Philipp Schmidt
--
-- This program is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to:
--
-- Free Software Foundation, Inc.,
-- 51 Franklin Street, Fifth Floor,
-- Boston, MA  02110-1301, USA.
--
--
------------------------------------------------------------------------


-- We keep the Ace3 dependency to a minimum
local L = AceLibrary("AceLocale-2.2"):new("GridStatusAbsorbsMonitor")

L:RegisterTranslations("enUS",
	function()
		return
{
	["Absorb effects left"] = true,
}

	end
);

L:RegisterTranslations("deDE",
	function()
		return
{
	["Absorb effects left"] = "Verbleibende Absorptionseffekte",
}

	end
);

L:RegisterTranslations("frFR",
	function()
		return
{
	["Absorb effects left"] = "Effets absorbés sur la gauche",
}

	end
);


local GridStatusAbsorbsMonitor = Grid:GetModule("GridStatus"):NewModule("GridStatusAbsorbsMonitor");
GridStatusAbsorbsMonitor.menuName = L["Absorb effects left"];

-- AceEvent2 has no support for local addon messages
-- sent by AceEvent3
-- we cannot embed it though, since we could screw
-- the mixin's from grid
local AceEvent = LibStub("AceEvent-3.0");


GridStatusAbsorbsMonitor.defaultDB = {
	unitAbsorbsLeft = {
		enable = true,
		priority = 90,
		color = { r = 1, g = 0, b = 0, a = 1 },
	},
};

local GridStatusAM_profile;


-- To prevent table allocation on every update
local color = {r = 0, g = 0, b = 0, a = 0.5};


function GridStatusAbsorbsMonitor:OnInitialize()
	self.super.OnInitialize(self)
	self:RegisterStatus("unitAbsorbsLeft", L["Absorb effects left"], nil, true)	
	GridStatusAM_profile = self.db.profile.unitAbsorbsLeft;
end

function GridStatusAbsorbsMonitor:OnEnable()
    self:RegisterEvent("Grid_UnitJoined");
    
    AceEvent.RegisterMessage(GridStatusAbsorbsMonitor, "Absorbs_UnitUpdated");
    AceEvent.RegisterMessage(GridStatusAbsorbsMonitor, "Absorbs_UnitCleared");
end

function GridStatusAbsorbsMonitor:OnDisable()
	AceEvent.UnregisterMessage(GridStatusAbsorbsMonitor, "Absorbs_UnitUpdated");
	AceEvent.UnregisterMessage(GridStatusAbsorbsMonitor, "Absorbs_UnitCleared");
end

function GridStatusAbsorbsMonitor:Grid_UnitJoined(guid, unitId)
    self.core:SendStatusLost(guid, "unitAbsorbsLeft");
end

-- obj is the same as self, but it gets called by the . operator
-- within AceEvent3
function GridStatusAbsorbsMonitor:Absorbs_UnitUpdated(obj, guid, value, quality)
	local shieldText;
	
	if(value > 999) then
		shieldText = string.format("%.1fk", value / 1000.0);
	else
		shieldText = string.format("%3.0f", value);
	end
	
	color.r = 1 - quality;
	color.g = quality;
	--color.a = 0.3 + (quality * 0.3);

	self.core:SendStatusGained(guid, "unitAbsorbsLeft", GridStatusAM_profile.priority, nil, color, shieldText)
end

function GridStatusAbsorbsMonitor:Absorbs_UnitCleared(obj, guid)
	self.core:SendStatusLost(guid, "unitAbsorbsLeft")
end
